==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebColumnVisibilityChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata } from "./WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangedEventArgsDescription } from "./WebColumnVisibilityChangedEventArgsDescription";
/**
 * @hidden
 */
var WebColumnVisibilityChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnVisibilityChangedEventArgsDescriptionMetadata, _super);
    function WebColumnVisibilityChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnVisibilityChangedEventArgsDescriptionMetadata.a == null) {
            WebColumnVisibilityChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnVisibilityChangedEventArgsDescriptionMetadata.c(WebColumnVisibilityChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebColumnVisibilityChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnVisibilityChangedEventArgsDescriptionMetadata.a);
        WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnVisibilityChangedEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebColumnVisibilityChangedEventArgsDetail");
    };
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.d = function (a) {
        WebColumnVisibilityChangedEventArgsDescriptionMetadata.b(a);
        a.aa("WebColumnVisibilityChangedEventArgs", function () { return new WebColumnVisibilityChangedEventArgsDescription(); });
        a.z("WebColumnVisibilityChangedEventArgs", WebColumnVisibilityChangedEventArgsDescriptionMetadata.a);
    };
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.$t = markType(WebColumnVisibilityChangedEventArgsDescriptionMetadata, 'WebColumnVisibilityChangedEventArgsDescriptionMetadata');
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.a = null;
    return WebColumnVisibilityChangedEventArgsDescriptionMetadata;
}(Base));
export { WebColumnVisibilityChangedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebColumnVisibilityChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata } from "./WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata";
import { WebColumnVisibilityChangedEventArgsDescription } from "./WebColumnVisibilityChangedEventArgsDescription";
/**
 * @hidden
 */
var WebColumnVisibilityChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnVisibilityChangedEventArgsDescriptionMetadata, _super);
    function WebColumnVisibilityChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.b = function (a) {
        if (WebColumnVisibilityChangedEventArgsDescriptionMetadata.a == null) {
            WebColumnVisibilityChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnVisibilityChangedEventArgsDescriptionMetadata.c(WebColumnVisibilityChangedEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebColumnVisibilityChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnVisibilityChangedEventArgsDescriptionMetadata.a);
        WebColumnVisibilityChangedEventArgsDetailDescriptionMetadata.d(a);
    };
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ColumnVisibilityChangedEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebColumnVisibilityChangedEventArgsDetail");
    };
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.d = function (a) {
        WebColumnVisibilityChangedEventArgsDescriptionMetadata.b(a);
        a.ac("WebColumnVisibilityChangedEventArgs", function () { return new WebColumnVisibilityChangedEventArgsDescription(); });
        a.ab("WebColumnVisibilityChangedEventArgs", WebColumnVisibilityChangedEventArgsDescriptionMetadata.a);
    };
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.$t = markType(WebColumnVisibilityChangedEventArgsDescriptionMetadata, 'WebColumnVisibilityChangedEventArgsDescriptionMetadata');
    WebColumnVisibilityChangedEventArgsDescriptionMetadata.a = null;
    return WebColumnVisibilityChangedEventArgsDescriptionMetadata;
}(Base));
export { WebColumnVisibilityChangedEventArgsDescriptionMetadata };
